% GluSnFR simulations (radially symmetric)
% December 16, 2019

%---------- General Model Parameters -------------------
tsf=1;                                      %time step (s)
numtrials=10;                                %Run simulations multiple times and average
simdur=30000;
numparticles=5000;                          %number of transmitter molecules
numsteps=ceil(simdur/tsf);                  %time steps
radialvector=[0.5 1 2 5 10 25 50 100 10000];%ROI sizes to track
gVm=-70;                                    %glial resting potential
nVm=-70;                                    %neuronal resting potential
wcleft = 0.02;                              %Cleft width (i.e., z dimension), in um (i.e., 20 nm)
rpsd = 0.110;                               %radius, in um, of PSD (Ventura and Harris, 1999)
rcleft =0.160;                             %radius, in um, of axon-spine interface (Ventura and Harris, 1999)
rperi = 0.200;                              %outer radius of perisynaptic region
if(rpsd>rcleft)                             %rpsd cannot exceed rcleft
    rpsd=rcleft;
end
numshells=1000;                              %number of radially symmetric shells
shellthickness = 0.01;                      %each shell is the same thickness (um)
tort=1.5;                                   %tortuosity index (Nicholson)
vf=0.21;                                    %volume fraction (Nicholson)
Q10=1;                                      %temperature dependence (1=room temp)
Dcleft=0.000253;                            %Diffusion constant in cleft
D=0.000253/(tort^2);                        %Exrtasynaptic dfifusion constant, corrected for tortuosity
rdiff = sqrt(2*D*tsf);                      %1-D rms distance in one time step
rdiffc = sqrt(2*Dcleft*tsf);                %diff length in cleft (2D)
PSDvolume=1e-15*wcleft*pi*(rpsd^2);         %volume of the cleft above the PSD (L)
cleftvolume = 1e-15*wcleft*pi*(rcleft^2);   %volume of cleft (L)
perivolume = 1e-15*wcleft*pi*(rperi^2-rcleft^2); %volume of "perisynaptic" region surrounding cleft region (L)
 
%Ion/glu concentrations
gluin= 0.00001;                             %glial intracellular glu = 10 uM
Nain = 0.005;                               %glial intracellular Na = 5 mM
Kin = 0.120;                                %glial intracellular K = 120 mM
Hin = 3.98107e-08;                          %glial pH 7.4

ngluin= 0.00001;                            %neuronal intracellular glu = 10 uM
nNain = 0.005;                              %neuronal intracellular Na = 5 mM
nKin = 0.120;                               %neuronal intracellular K = 120 mM
nHin = 3.98107e-08;                         %neuronal intracellular pH 7.4

Naout=0.1462;                               %extracellular Na = 146.2 mM 
Kout = 0.0025;                              %extracellular K = 2.5 mM
Hout = 3.98107e-08;                         %extracellular pH 7.4

%------------ Arrays for averages (multiple trials)--------
ave=zeros(numsteps,size(radialvector,2));                   %time steps, ROI size, multi
AveSTC=zeros(numsteps,1);                              %surrogate for the glial transporter current
%----------------------------------------------------------

for k=1:numtrials               %----------TOP OF THE MULTIPLE TRIALS LOOP------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Transporter density/concentration
EAATconc = zeros(numshells,1);             %Keep track of available glial transporters in each shell
EAATconc(:)= 1.0E-4;                       %EAAT concentration (M): 125 uM corresponds to 10,800 per um2 (Danbolt)
GluSnFRconc = zeros(numshells,1);
GluSnFRconc(:) = 0;%3.0E-4;
GluSnFRtype = 2;                           %1=iGluSnFR@34C, 2=iGluSnFR@20C, 3=Gluf@34C, 4=Gluf@20C
                                           %5=iGluu@34C, 6=iGluu@20C,
                                           %7=SuperGluSnFR
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Construct shells around synapse to track glu concentration, uptake, etc.
radial = ones(numparticles,1);             %distance of each transmitter particle from release site (origin)
whichparticle = zeros(numparticles,1);      %identifier number for each glutamate molecule
whichshell=zeros(numshells,1);
for i=1:numparticles
    whichparticle(i)=i;
end
for i=1:numshells
    whichshell(i)=i;
end
glowflag = zeros(numparticles,1);           %Is the particle is bound to a fluorescing iGluSnFR?
whichorder = zeros(numparticles,1);         %saves the order in which each glutamate molecule is taken up
shell = zeros(numparticles,1);              %Which shell does each glutamate molecule occupy
bp = zeros(numparticles,1);                 %EAAT binding prob for each particle
gbp = zeros(numparticles,1);                %iGluSnFR binding prob for each particle
whichcounter = 0;                           %counter for how many molecules have been taken up
shellradius = zeros(numshells,1);           %vector containing all the shell radii
shellvolume = zeros(numshells,1);           %shell volumes (liters) -- volume difference between consecutive spheres
shelltrans=zeros(numshells,1);              %number of free (unbound) transporters in each shell
unitconc=zeros(numshells,1);                %concentration per single molecule in its shell
rtd = ones(numshells,1);                    %relative transporter density (default: uniform)
GluSnFRtrac = zeros(numsteps,1);
shellGluSnFR=zeros(numshells,1);            %number of free (unbuond) iGluSnFR moelcules in each shell
for i=1:numshells
    shellradius(i)=rperi+i*shellthickness;
    shellvolume(i)=(1e-15)*(4/3)*pi*((rperi+i*shellthickness)^3-(rperi+(i-1)*shellthickness)^3)*vf;  %liters
    unitconc(i)=(1/6.022e23)/shellvolume(i);%concentration of a single molecule, moles per liter
    if(mod(i,400)<200)
        %shellGluSnFR(i) = (100/10)*6.022e23*GluSnFRconc(i)*shellvolume(i);  %calculate the number of GluSnFR molecules in each shell
        shelltrans(i) = 2*6.022e23*EAATconc(i)*rtd(i)*shellvolume(i);  %calculate the number of transporters in each shell (note: .* is vector multiplication)
    end
    if(mod(i,400)>=200)
        shellGluSnFR(i) = 2*6.022e23*GluSnFRconc(i)*shellvolume(i);  %calculate the number of GluSnFR molecules in each shell
        %shelltrans(i) = (100/90)*6.022e23*EAATconc(i)*rtd(i)*shellvolume(i);  %calculate the number of transporters in each shell (note: .* is vector multiplication)
    end
end
%shelltrans = 6.022e23.*EAATconc.*rtd.*shellvolume;  %Number of transporters in each shell
%shellGluSnFR = 6.022e23.*GluSnFRconc.*shellvolume;  %Number of GluSnFR molecules in each shell
shelltrans(1:2)=0;                                  %no glial transporters in first two shells (usually 20 nm) outside of cleft
shellGluSnFR(1:2)=0;                                %no iGluSnFRs in first two shells (usually 20 nm) outside of cleft
EAAT0=shelltrans;                               %original number of transporters (in each shell)
GluSnFR0=shellGluSnFR;                           %original number of GluSnFR molecules (in each shell)

 %----------- Counter arrays, etc. -----------------------
STC=zeros(numsteps,1);                              %surrogate for the glial transporter current
dFF=zeros(numsteps,10);                             %GluSnFR signal: time steps, volumes, multi
cumSTC=zeros(numsteps,1);
GLTtouches = zeros(numsteps,1);                     %number of times EAAC1 binds glutamate
cumGLTtouches = zeros(numsteps,1);                  %number of times EAAC1 binds glutamate
GLTEfficiency = zeros(numsteps,1);                  %cumNTC/cumEAAC1touches
GLTEfficiency(:)=NaN;
EAATtouches = zeros(numparticles,1);
snifftouch = zeros(numparticles,1);
trialcounter=zeros(numtrials,1);                    %counters for glutamate, etc.
counter1=zeros(numsteps,1);                         %counters for glutamate, etc.
counter2=zeros(numsteps,1);
counter3=zeros(numsteps,1);
counter4=zeros(numsteps,1);
counter5=zeros(numsteps,1);
counter6=zeros(numsteps,1);
counter7=zeros(numsteps,1);
counter8=zeros(numsteps,1);
counter9=zeros(numsteps,1);

if(rcleft==0)                               %if cleft is infinitely small, everything is outside it
    outcleft=ones(numparticles,1); 
else
    outcleft=zeros(numparticles,1);         %flag that particle has escaped the cleft (2D-->3D diffusion)
end
endpoint=zeros(numparticles,1);             %site of uptake, radial distance from release
endpoint(:)=NaN;
endtime=zeros(numparticles,1);              %time of uptake
endtime(:)=NaN;
free=ones(numparticles,1);                  %free to diffuse
EAATbound=zeros(numparticles,1);            %bound to EAAT
iGlubound=zeros(numparticles,1);            %bound to iGluSnFR
transported=zeros(numparticles,1);          %flag that a particle has been taken up
cycled=zeros(numparticles,1);               %flag that transport cycle has been completed
position=zeros(numparticles,2,3);           %3-D position of each transmitter particle
positionecho=zeros(numparticles,1,3);       %3-D position of each transmitter particle
position0=position;                         %original 3-D position of each transmitter particle

%---------- Transporter Kinetic Schemes -------------------

%GLT-1, according to Bergles, et al. (2002)
%each rate is multiplied by Q10, the time step fraction, and a s>s conversion

vfactor1= exp((96486*(gVm+70)/1000*0.46)/(2*8.3143*298));
vfactor7 = exp((96486*(gVm+70)/1000*0.55)/(2*8.3143*298));
%vfactor9=  exp((0.1*96486*(gVm+70)/1000*0.4)/(2*8.3143*298));
vfactor9f=  exp((0.1*96486*(gVm+70)/1000*0.4)/(2*8.3143*298));
vfactor9b=  exp(((1-0.1)*96486*(gVm+70)/1000*0.4)/(2*8.3143*298));
vfactor15f= exp((0.9*96486*(gVm+70)/1000*0.59)/(2*8.3143*298));
vfactor15b= exp(((1-0.9)*96486*(gVm+70)/1000*0.59)/(2*8.3143*298));

k1f = Q10*tsf*1e-6*Naout*1e4/vfactor1;          %extracellular Na dependent (120 mM)
k1b = Q10*tsf*1e-6*1e2*vfactor1;
k2f = Q10*tsf*1e-6*Naout*1e4;                   %extracellularNa dependent
k2b = Q10*tsf*1e-6*5e2;
k3f = Q10*tsf*1e-6*6e6;                         %extracellular glutamate dependent
k3b = Q10*tsf*1e-6*5e2;
k4f = Q10*tsf*1e-6*Hout*6e11;                   %proton dependent (pH 7.4)
k4b = Q10*tsf*1e-6*7e2;
%k5f = Q10*tsf*1e-6*Hout*6e11;                   %proton dependent (pH 7.4)
%k5b = Q10*tsf*1e-6*7e2;
k6f = Q10*tsf*1e-6*6e6;                         %extracellular glutamate dependent
k6b = Q10*tsf*1e-6*1e2;                         %glu unbinding, default 5e2
k7f = Q10*tsf*1e-6*Naout*1e4/vfactor7;          %extracellular Na
k7b = Q10*tsf*1e-6*1e3*vfactor7;
k8f = Q10*tsf*1e-6*2e3;                         %translocation
k8b = Q10*tsf*1e-6*1.9e3;
k9f = Q10*tsf*1e-6*1e3/vfactor9f;                %Na unbinding
k9b = Q10*tsf*1e-6*Nain*4e4*vfactor9b;           %intracellular Na dependent (10 mM)
k10f = Q10*tsf*1e-6*3e3;
k10b = Q10*tsf*1e-6*Hin*9e10;
k11f = Q10*tsf*1e-6*3e3;                        %intracellular glutamate unbinding
k11b = Q10*tsf*1e-6*gluin*1e5;
k12f = Q10*tsf*1e-6*1e5;
k12b = Q10*tsf*1e-6*Nain*2e7;
k13f = Q10*tsf*1e-6*1e5;
k13b = Q10*tsf*1e-6*Nain*1e8;
k14f = Q10*tsf*1e-6*Kin*1e6;
k14b = Q10*tsf*1e-6*1e3;
k15f = Q10*tsf*1e-6*40/vfactor15f;
k15b = Q10*tsf*1e-6*10*vfactor15b;
k16f = Q10*tsf*1e-6*2e4;
k16b = Q10*tsf*1e-6*Kout*1e6;
%k17f = Q10*tsf*1e-6*1.4;
%k17b = Q10*tsf*1e-6*Kout*0.01;
GLTstate = ones(numparticles,1);              %transporter state for bound glutamate molecules
GLTfrate=[k1f;k2f;k4f;k6f;k7f;k8f;k9f;k10f;k11f;k12f;k13f;k14f;k15f;k16f];
GLTbrate=[k16b;k1b;k2b;k4b;k6b;k7b;k8b;k9b;k10b;k11b;k12b;k13b;k14b;k15b];
%GLTsrate=[0,0,k17f,0,0,0,0,0,0,k17b,0,0,0,0];   %not used in current iteration

%iGluSnFR kinetic schemes (Halassa et al (2018) PNAS)
switch GluSnFRtype                  %iGluSnFR @ 34C
    case 1
        gk1f = tsf*1e-6*2.8e7;
        gk1b = tsf*1e-6*8161;
        gk2f = tsf*1e-6*756;
        gk2b = tsf*1e-6*220;
    case 2                          %iGluSnFR @ 20C
        gk1f = tsf*1e-6*2.7e7;
        gk1b = tsf*1e-6*5965;
        gk2f = tsf*1e-6*569;
        gk2b = tsf*1e-6*110;
    case 3                          %Gluf @ 34C
        gk1f = tsf*1e-6*3.63e6;
        gk1b = tsf*1e-6*3018;
        gk2f = tsf*1e-6*1254;
        gk2b = tsf*1e-6*566;
    case 4                          %Gluf @ 20C
        gk1f = tsf*1e-6*3.5e6;
        gk1b = tsf*1e-6*2206;
        gk2f = tsf*1e-6*944;
        gk2b = tsf*1e-6*283;
    case 5                          %Gluu @ 34C
        gk1f = tsf*1e-6*2.28e6;
        gk1b = tsf*1e-6*2331;
        gk2f = tsf*1e-6*180.7;
        gk2b = tsf*1e-6*936;
    case 6                          %Gluu @ 20C
        gk1f = tsf*1e-6*2.2e6;
        gk1b = tsf*1e-6*1704;
        gk2f = tsf*1e-6*136;
        gk2b = tsf*1e-6*468;
    case 7                          %FrankenSnFR
        gk1f = tsf*1e-6*3.5e7;
        gk1b = tsf*1e-6*2500;
        gk2f = tsf*1e-6*2000;
        gk2b = tsf*1e-6*600;
end
GluSnFRstate = ones(numparticles,1);
GluSnFRfrate=[gk1f;gk2f;0];
GluSnFRbrate=[0;gk1b;gk2b];
tvect=tsf.*(1:numsteps);

%-------------------------------- BIG LOOP --------------------------------
trialcounter(k)=1;
for i=2:numsteps                            %loop for every point in time
    position(:,1,:)=position(:,2,:);        %1 is old position, 2 is new position

    %Calculate new 3-D position of each particle
    diffcleft=free.*rdiffc.*randn(numparticles,1,3);
    diff=free.*rdiff.*randn(numparticles,1,3);
    position(:,2,:)=position(:,1,:)+(((1-outcleft).*diffcleft)+(outcleft.*diff));
    radial=sqrt(position(:,2,1).^2+position(:,2,2).^2+position(:,2,3).^2);
    outcleft(radial>rcleft)=1;
    X=find((abs(position(:,2,3)).*free.*(1-outcleft))>(wcleft/2));
    while(size(X,1)>0)
         diffcleft=rdiffc.*randn(numparticles,1);
         diff=rdiff.*randn(numparticles,1);
         position(X,2,:)=position(X,1,:)+free(X).*(((1-outcleft(X)).*diffcleft(X))+(outcleft(X).*diff(X)));
         radial(X)=sqrt(position(X,2,1).^2+position(X,2,2).^2+position(X,2,3).^2);
         outcleft(radial>rcleft)=1;
         X=find(abs(position(:,2,3).*free.*(1-outcleft))>(wcleft/2));
    end
    X=find(((outcleft==1).*(radial<rcleft))>0);
    while(size(X,1)>0)
        diff=rdiff.*randn(numparticles,1,3);
        position(X,2,:)=position(X,1,:)+diff(X,:,:);
        radial(X)=sqrt(position(X,2,1).^2+position(X,2,2).^2+position(X,2,3).^2);
        outcleft(radial>rcleft)=1;
        X=find((outcleft==1).*(radial<rcleft));
    end
    positionecho(:,1,:)=position(:,2,:);
        
    %Tracking glutamate concentraion over time and space 
    glunum=transpose(histcounts(radial,shellradius));      %counts number of glutamate particles in each shell
    glunum(numshells)=0;                        %largest shell set to empty (for some reason)
    gluconc=glunum./(6.022e23)./shellvolume;    %glutamate concentration in each extrasynaptic shell
    shell=ceil((radial-rcleft)/shellthickness); %in which shell is particle located?
    shell(shell>numshells)=numshells;
    shell(shell<1)=1;
    bp = k6f*unitconc(shell).*shelltrans(shell);         %EAAT2
    gbp = gk1f*unitconc(shell).*shellGluSnFR(shell);     %GluSnFR
    mprob=rand(numparticles,1);
    
    %Determine fate of each particle during the time step
    inplay=free.*(1-cycled);        %Free particles
    %EAATs
    X=find(free.*(EAATbound==0).*(mprob<(bp.*inplay)));     %Particles that bind EAAT during this step
        %Particles that bound EAAT during the last step
    Xf=find((EAATbound==1).*(mprob<GLTfrate(GLTstate))); %particles going forward
    Xb=find((EAATbound==1).*(mprob>=GLTfrate(GLTstate))&(mprob<(GLTfrate(GLTstate)+GLTbrate(GLTstate)))); %particles going backward
    trans_ind=sub2ind(size(shelltrans),shell(X));
    GLTstate(X)=5;                                  %EAAT bound state
    EAATbound(X)=1;
    free(X)=0;
    EAATtouches(X)=EAATtouches(X)+1;
    shelltrans(trans_ind)=shelltrans(trans_ind)-1;  %reduce available transporters
    %iGluSnFR
    Y=find((iGlubound==0).*(mprob>=(bp.*inplay)).*(mprob<((bp+gbp).*inplay))); %Particles that bind iGluSnFR during this step
    iglu_ind=sub2ind(size(shellGluSnFR),shell(Y));
        %Particles that bound iGluSnFR during the last step
    Y23=find((GluSnFRstate==2)&(mprob<GluSnFRfrate(2)));    %iGlu 2-->3
    Y21=find((GluSnFRstate==2)&(mprob>=GluSnFRfrate(2))&(mprob<(GluSnFRfrate(2)+GluSnFRbrate(2))));   %iGlu 2-->1
    GluSnFRstate(Y)=2;                  %iGluSnFR bound state
    iGlubound(Y)=1;
    free(Y)=0;
    snifftouch(Y)=snifftouch(Y)+1;
    shellGluSnFR(iglu_ind)=shellGluSnFR(iglu_ind)-1;   %reduce available GluSnFR
        
    %Determine any state transitions in EAATs and iGluSnFRs

    %Particles bound to EAAT
    nXf=(EAATbound==1).*(mprob<GLTfrate(GLTstate)); %particles going forward
    nXb=(EAATbound==1).*(mprob>=GLTfrate(GLTstate))&(mprob<(GLTfrate(GLTstate)+GLTbrate(GLTstate))); %particles going backward
    Xf14=find(nXf.*(GLTstate==14));                        %14-->1
    nXf14=nXf.*(GLTstate==14);
    STC(i)=STC(i)-sum(nXf14);
    Xf14_ind=sub2ind(size(shelltrans),shell(Xf14));
    shelltrans(Xf14_ind)=shelltrans(Xf14_ind)+1;            %increment EAAT
    cycled(Xf14)=1;
    Xb1=find(nXb.*(GLTstate==1));                          %1-->14
    GLTstate(Xf)=GLTstate(Xf)+1;
    GLTstate(Xb)=GLTstate(Xb)-1;
    GLTstate(Xf14)=1;
    GLTstate(Xb1)=14;
    X54=find(nXb&(GLTstate==4));                      %5-->4
    X54_ind=sub2ind(size(shelltrans),shell(X54));
    shelltrans(X54_ind)=shelltrans(X54_ind)+1; %transporter back in play
    EAATbound(X54)=0;
    free(X54)=1;
    X12=find(nXf.*(GLTstate==2));                     %1-->2
    nX12=nXf.*(GLTstate==2);                        
    STC(i)=STC(i)+sum(nX12);
    X78=find(nXf.*(GLTstate==8));                     %7-->8
    nX78=nXf.*(GLTstate==8);                        
    STC(i)=STC(i)+sum(nX78);
    X910=find(nXf.*(GLTstate==10));                   %9-->10 (transported)
    nX910=nXf.*(GLTstate==10);                        
    transported(X910)=1;
    STC(i)=STC(i)+sum(nX910);
    EAATbound(X910)=0;
    endpoint(X910)=sqrt((position(X910,2,1)-position0(X910,1,1)).^2+(position(X910,2,2)-position0(X910,1,2)).^2+(position(X910,2,3)-position0(X910,1,3)).^2);
    whichcounter=whichcounter+sum(nX910);
    whichorder(X910)=whichcounter;
    endtime(X910)=i*tsf;
    positionecho(X910,1,:)=NaN;

    %Particles bound to iGluSnFR
    iglu_23_ind=sub2ind(size(shellGluSnFR),shell(Y23));
    iglu_21_ind=sub2ind(size(shellGluSnFR),shell(Y21));
    Y32=find((GluSnFRstate==3)&(mprob<GluSnFRbrate(3)));
    GluSnFRstate(Y23)=3;
    GluSnFRstate(Y21)=1;
    GluSnFRstate(Y32)=2;
    shellGluSnFR(iglu_21_ind)=shellGluSnFR(iglu_21_ind)+1;   %increment GluSnFR
    iGlubound(Y21)=0;
    free(Y21)=1;
    glowflag(:)=0;
    gf=find(GluSnFRstate==3);
    glowflag(gf)=1;      %State #3 glows

    %Update iGluSnFR counters
    for v=1:size(radialvector,2)
        dFF(i,v)=sum((GluSnFRstate==3).*(radial<radialvector(v)));
    end
    cumSTC(i)=size(find(transported>0),1);
    
    counter1(i)=sum(free.*(radial>.4)&(radial<=.5));
    counter2(i)=sum((EAATbound==1).*(radial>.4)&(radial<=.5));
    counter3(i)=sum((iGlubound==1).*(radial>.4)&(radial<=.5));
    counter4(i)=sum(free.*(radial>.85)&(radial<=.95));
    counter5(i)=sum((EAATbound==1).*(radial>.85)&(radial<=.95));
    counter6(i)=sum((iGlubound==1).*(radial>.85)&(radial<=.95));
    counter7(i)=sum(free.*(radial>4)&(radial<=6));
    counter8(i)=sum((EAATbound==1).*(radial>4)&(radial<=6));
    counter9(i)=sum((iGlubound==1).*(radial>4)&(radial<=6));
       
    cumGLTtouches(i)=cumGLTtouches(i-1)+GLTtouches(i);

    %---------------- Update plot ----------------------------
    if(mod(i,500)==0 || i==2)
        delete(findall(gcf,'type','annotation'))
        
        subplot(3,2,1)
        plot(tvect, STC)
        axis([0 (numsteps*tsf) 0 5])
        axis 'auto y'
        title('Transporter Current')
        
        subplot(3,2,2)
        plot(whichparticle,shell)
        axis([0 (numparticles) 0 numshells])
        title('Glu in shells')

        subplot(3,2,3)
        plot(tvect,counter1) 
        axis([0 (numsteps*tsf) -1 2])
        axis 'auto y'
        title('Glu conc @ 1 NND')
               
        subplot(3,2,4)
        scatter3(positionecho(:,1,1),positionecho(:,1,2),positionecho(:,1,3),4,'.')
        axis([-5 5 -5 5 -5 5])
        title('3-D diffusion map')

        subplot(3,2,5)
        plot(tvect, cumSTC)
        axis([0 (numsteps*tsf) 0 numparticles])
        axis 'auto y'
        title('Glu molecules taken up')

        subplot(3,2,6)
        plot(tvect,dFF(:,1),tvect,dFF(:,2),tvect,dFF(:,3),tvect,dFF(:,4),tvect,dFF(:,5),tvect,dFF(:,6),tvect,dFF(:,7),tvect,dFF(:,8))
        axis([0 (numsteps*tsf) 0 200])
        axis 'auto y'
        title('GluSnFR signal')
        dim=[.1 .9 .3 .1];
        str="Trial number: "+num2str(k);
        h=annotation('textbox',dim,'LineStyle','none','String',str);
        drawnow;
    end
end         % -------------- END OF THE TIME STEP LOOP -----------------
    for h=1:size(radialvector,2)
            ave(:,h)= ave(:,h) + dFF(:,h);
    end
    AveSTC=AveSTC+STC;

end         %------------ END OF MULTIPLE TRIALS LOOP

ave=ave/numtrials;
AveSTC=AveSTC/numtrials;
writematrix(ave,"aves.dat")
beep;
    counter1_ave=counter1/numtrials/tsf;
    counter2_ave=counter2/numtrials/tsf;
    counter3_ave=counter3/numtrials/tsf;
    counter4_ave=counter4/numtrials/tsf;
    counter5_ave=counter5/numtrials/tsf;
    counter6_ave=counter6/numtrials/tsf;
    counter7_ave=counter7/numtrials/tsf;
    counter8_ave=counter8/numtrials/tsf;
    counter9_ave=counter9/numtrials/tsf;
    csvwrite('counter1.dat',counter1_ave);
    csvwrite('counter2.dat',counter2_ave);
    csvwrite('counter3.dat',counter3_ave);
    csvwrite('counter4.dat',counter4_ave);
    csvwrite('counter5.dat',counter5_ave);
    csvwrite('counter6.dat',counter6_ave);
    csvwrite('counter7.dat',counter7_ave);
    csvwrite('counter8.dat',counter8_ave);
    csvwrite('counter9.dat',counter9_ave);
    csvwrite('endpoint.dat',endpoint);
    csvwrite('shelltrans.dat',shelltrans);
    csvwrite('shellGluSnFR.dat',shellGluSnFR);
    csvwrite('shell.dat',shell);
    csvwrite('GluSnFR0.dat',GluSnFR0);
    csvwrite('GluSnFRtouches.dat',snifftouch);
    csvwrite('EAATtouches.dat',EAATtouches);
    csvwrite('CumUptake.dat',cumSTC);
    csvwrite('AveSTC.dat',AveSTC);
beep;